probnum.diffeq
==============

Differential Equations.

This package defines common dynamical models and probabilistic solvers for differential
equations.

.. automodapi:: probnum.diffeq
    :no-heading:
    :no-main-docstr:
